@@ -1,8 +1,7 @@
 package Crypt::SecretBuffer::AsyncResult;
-# VERSION
-# ABSTRACT: Observe results of a write_async operation
-$Crypt::SecretBuffer::AsyncResult::VERSION = '0.017_002'; # TRIAL
-$Crypt::SecretBuffer::AsyncResult::VERSION = '0.017002';
+$Crypt::SecretBuffer::AsyncResult::VERSION = '0.001';
+#ABSTRACT: Observe results of a write_async operation
+#VERSION
 1;
 
 __END__
@@ -17,8 +16,8 @@ Crypt::SecretBuffer::AsyncResult - Observe results of a write_async operation
 
 =head1 DESCRIPTION
 
-This object holds a reference to a background write operation started by
-L<Crypt::SecretBuffer/write_async>.
+This object holds a reference to a background write operation started by L<Crypt::SecretBuffer::write_async>.
+There is only one method currently:
 
 =head1 METHODS
 
@@ -29,12 +28,12 @@ L<Crypt::SecretBuffer/write_async>.
   }
 
 This waits up to C<$seconds> (or indefinitely if you pass undef) for the write operation to
-complete.  If it has completed, this returns the number of bytes written and the OS error code
-as a list.  On a timeout, it returns an empty list.
+complete, then if it has completed, returns the number of bytes written, and the OS error code,
+if any.
 
 =head1 VERSION
 
-version 0.017_002
+version 0.001
 
 =head1 AUTHOR
 
@@ -42,7 +41,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2026 by Michael Conrad.
+This software is copyright (c) 2025 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
